SensorAngle

Trait SensorAngle 

pub trait SensorAngle {
    // Required method
    fn get_angle(&mut self) -> Result<I16F16>;
}
The trait for getting the shaft angle of the motor from some sensor

Required Methods

fn get_angle(&mut self) -> Result<I16F16>

Retrieve the angle from the sensor, in a synchrounous way Return on success the raw angle from the sensor, in radians from 0 .. 2 pi

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors