pub trait SensorCurrent {
// Required method
fn get_current(&mut self) -> Result<[I16F16; 3]>;
}Required Methods
Sourcefn get_current(&mut self) -> Result<[I16F16; 3]>
fn get_current(&mut self) -> Result<[I16F16; 3]>
Retrieve the current from the sensor. Return on success the current array from the sensor, in amperes In case 2 phases are sample set the third phase to zero here
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".